{
    "$graph": [
        {
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#capture_kit.yml/capture_kit_set_file",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#capture_kit.yml/capture_kit_set_file/capture_kit_bait_file",
                                    "type": "File"
                                },
                                {
                                    "name": "#capture_kit.yml/capture_kit_set_file/capture_kit_target_file",
                                    "type": "File"
                                }
                            ]
                        },
                        {
                            "name": "#capture_kit.yml/capture_kit_set_uuid",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#capture_kit.yml/capture_kit_set_uuid/capture_kit_bait_uuid",
                                    "type": "string"
                                },
                                {
                                    "name": "#capture_kit.yml/capture_kit_set_uuid/capture_kit_bait_file_size",
                                    "type": "long"
                                },
                                {
                                    "name": "#capture_kit.yml/capture_kit_set_uuid/capture_kit_target_uuid",
                                    "type": "string"
                                },
                                {
                                    "name": "#capture_kit.yml/capture_kit_set_uuid/capture_kit_target_file_size",
                                    "type": "long"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "class": "ExpressionTool",
            "inputs": [
                {
                    "id": "#emit_capture_kit_file.cwl/capture_kit_bait_file",
                    "type": "File"
                },
                {
                    "id": "#emit_capture_kit_file.cwl/capture_kit_target_file",
                    "type": "File"
                }
            ],
            "expression": "${\n  var output = {'capture_kit_bait_file': inputs.capture_kit_bait_file,\n                'capture_kit_target_file': inputs.capture_kit_target_file};\n  return {'output': output};\n}\n",
            "id": "#emit_capture_kit_file.cwl",
            "outputs": [
                {
                    "id": "#emit_capture_kit_file.cwl/output",
                    "type": "#capture_kit.yml/capture_kit_set_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/curl:c0a4eaf9b928f14db71fa28fcc928b602e74dbfd168a3d761a134b0ba5ec6d94"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 2000,
                    "ramMax": 2000,
                    "tmpdirMin": "$(Math.ceil (inputs.file_size / 1048576))",
                    "tmpdirMax": "$(Math.ceil (inputs.file_size / 1048576))",
                    "outdirMin": "$(Math.ceil (inputs.file_size / 1048576))",
                    "outdirMax": "$(Math.ceil (inputs.file_size / 1048576))"
                }
            ],
            "inputs": [
                {
                    "id": "#gdc_get_object.cwl/gdc_token",
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true,
                        "valueFrom": "$(null)"
                    }
                },
                {
                    "id": "#gdc_get_object.cwl/gdc_uuid",
                    "type": "string"
                },
                {
                    "id": "#gdc_get_object.cwl/file_size",
                    "type": "long",
                    "default": 1
                }
            ],
            "outputs": [
                {
                    "id": "#gdc_get_object.cwl/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    }
                }
            ],
            "arguments": [
                {
                    "valueFrom": "X-Auth-Token: $(inputs.gdc_token.contents)",
                    "position": 0
                },
                {
                    "valueFrom": "https://api.gdc.cancer.gov/data/$(inputs.gdc_uuid)",
                    "position": 1
                }
            ],
            "baseCommand": [
                "curl",
                "--remote-name",
                "--remote-header-name",
                "--header"
            ],
            "id": "#gdc_get_object.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#capture_kit.yml/capture_kit_set_file"
                        },
                        {
                            "$import": "#capture_kit.yml/capture_kit_set_uuid"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#main/gdc_token",
                    "type": "File"
                },
                {
                    "id": "#main/capture_kit_set_uuid",
                    "type": "#capture_kit.yml/capture_kit_set_uuid"
                }
            ],
            "outputs": [
                {
                    "id": "#main/output",
                    "type": "#capture_kit.yml/capture_kit_set_file",
                    "outputSource": "#main/emit_capture_kit/output"
                }
            ],
            "steps": [
                {
                    "id": "#main/extract_capture_kit_bait",
                    "run": "#gdc_get_object.cwl",
                    "in": [
                        {
                            "id": "#main/extract_capture_kit_bait/gdc_token",
                            "source": "#main/gdc_token"
                        },
                        {
                            "id": "#main/extract_capture_kit_bait/gdc_uuid",
                            "source": "#main/capture_kit_set_uuid",
                            "valueFrom": "$(self.capture_kit_bait_uuid)"
                        },
                        {
                            "id": "#main/extract_capture_kit_bait/file_size",
                            "source": "#main/capture_kit_set_uuid",
                            "valueFrom": "$(self.capture_kit_bait_file_size)"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/extract_capture_kit_bait/output"
                        }
                    ]
                },
                {
                    "id": "#main/extract_capture_kit_target",
                    "run": "#gdc_get_object.cwl",
                    "in": [
                        {
                            "id": "#main/extract_capture_kit_target/gdc_token",
                            "source": "#main/gdc_token"
                        },
                        {
                            "id": "#main/extract_capture_kit_target/gdc_uuid",
                            "source": "#main/capture_kit_set_uuid",
                            "valueFrom": "$(self.capture_kit_target_uuid)"
                        },
                        {
                            "id": "#main/extract_capture_kit_target/file_size",
                            "source": "#main/capture_kit_set_uuid",
                            "valueFrom": "$(self.capture_kit_target_file_size)"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/extract_capture_kit_target/output"
                        }
                    ]
                },
                {
                    "id": "#main/emit_capture_kit",
                    "run": "#emit_capture_kit_file.cwl",
                    "in": [
                        {
                            "id": "#main/emit_capture_kit/capture_kit_bait_file",
                            "source": "#main/extract_capture_kit_bait/output"
                        },
                        {
                            "id": "#main/emit_capture_kit/capture_kit_target_file",
                            "source": "#main/extract_capture_kit_target/output"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/emit_capture_kit/output"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
